# <img src="https://esprit.tn/favicon.ico" width="28px" /> esprit-py

> [!NOTE]
> Please note that this library is not an official API provided by Esprit and is intended for educational and personal use only.

## Features

- Get your exact timetable pdf not 300 pages pdf
- Get your grades
- Get your absences
- Get your credits

missing stuff:
- [ ] download any time table from the esprit website , not only the last one
- [ ] post stuff (reclamation,document stage,teacher evaluation) *dangereous area tbh*

